pub fn delay_for_attempt(config: &RetryConfig, attempt: u32) -> DurationExpand description
Compute the delay for a given attempt number (0-based).
pub fn delay_for_attempt(config: &RetryConfig, attempt: u32) -> DurationCompute the delay for a given attempt number (0-based).